Modules
- graph
- Minimal graph adapter traits.
- node2vec
- Node2Vec / Node2Vec+ walk generation (OTF + PreComp).
- pagerank
- PageRank centrality.
- partition
- Graph partitioning / community detection.
- ppr
- Personalized PageRank.
- random_
walk - Random walk generation.
- reachability
- Reachability helpers (transitive closure counts).
- topk
- Ranking utilities.
Structs
- Adjacency
Matrix - Page
Rank Config - Page
Rank Run - Precomputed
Biased Walks - Precomputed alias tables for classic node2vec biased walks (unweighted).
- Walk
Config - Weighted
Node2 VecPlus Config - Parameters for weighted node2vec / node2vec+ walk generation.
Enums
Traits
- Graph
- Graph
Ref - A graph view that can return borrowed neighbor slices.
- Weighted
Graph - Weighted
Graph Ref - A weighted graph view that can return borrowed neighbor + weight slices.
Functions
- connected_
components - Connected components of an undirected graph, using BFS.
- generate_
biased_ walks - generate_
biased_ walks_ from_ nodes - Node2Vec-style biased walk generation, restricted to an explicit set of start nodes.
- generate_
biased_ walks_ precomp_ ref - generate_
biased_ walks_ precomp_ ref_ from_ nodes - Precomputed node2vec biased walks, restricted to an explicit set of start nodes.
- generate_
biased_ walks_ ref - Node2Vec-style biased walk generation for graphs that can return borrowed neighbor slices.
- generate_
biased_ walks_ ref_ from_ nodes - Node2Vec-style biased walk generation, restricted to an explicit set of start nodes.
- generate_
biased_ walks_ ref_ streaming_ from_ nodes - Streaming node2vec-style biased walk generation (borrowed neighbor slices).
- generate_
biased_ walks_ weighted_ plus_ ref - generate_
biased_ walks_ weighted_ ref - generate_
walks - generate_
walks_ from_ nodes - Random walk generation (unbiased), but restricted to an explicit set of start nodes.
- generate_
walks_ ref - Random walk generation for graphs that can return borrowed neighbor slices.
- generate_
walks_ ref_ from_ nodes - Random walk generation (unbiased), but restricted to an explicit set of start nodes.
- generate_
walks_ ref_ streaming_ from_ nodes - Streaming unbiased random walk generation (borrowed neighbor slices).
- label_
propagation - Label propagation community detection (Raghavan et al., 2007).
- normalize
- Normalize scores to sum to 1.0. No-op if sum is zero.
- pagerank
- Compute PageRank scores for all nodes.
- pagerank_
checked - Checked PageRank centrality.
- pagerank_
checked_ run - pagerank_
run - PageRank with convergence reporting.
- pagerank_
weighted - Weighted PageRank centrality.
- pagerank_
weighted_ checked - Checked weighted PageRank.
- pagerank_
weighted_ checked_ run - pagerank_
weighted_ run - personalized_
pagerank - Compute Personalized PageRank with a teleport bias.
- personalized_
pagerank_ checked - personalized_
pagerank_ checked_ run - personalized_
pagerank_ run - reachability_
counts_ edges - Count transitive reachability for each node in a directed graph.
- sample_
start_ nodes_ reservoir - Deterministically sample up to
kstart nodes from0..node_count. - top_k
- Return the top-k entries by score (descending).